//
//  RWTTutorialViewController.m
//  AppTutorial
//
//  Created by Main Account on 4/22/14.
//  Copyright (c) 2014 Razeware LLC. All rights reserved.
//

#import "RWTTutorialViewController.h"
#import "RWTTutorialStepViewController.h"

@interface RWTTutorialViewController () <UIScrollViewDelegate>

@property (weak, nonatomic) IBOutlet UIPageControl *pageControl;
@property (nonatomic, weak) IBOutlet UIScrollView *scrollView;
@property (nonatomic, strong) RWTTutorialStepViewController *step1VC;
@property (nonatomic, strong) RWTTutorialStepViewController *step2VC;
@property (nonatomic, strong) RWTTutorialStepViewController *step3VC;
@property (nonatomic, strong) RWTTutorialStepViewController *step4VC;
@property (nonatomic, strong) RWTTutorialStepViewController *step5VC;

@end

@implementation RWTTutorialViewController

- (RWTTutorialStepViewController *)createStepVCWithBgImageName:(NSString *)bgImageName iconImageName:(NSString *)iconImageName text:(NSString *)text {
  RWTTutorialStepViewController *stepVC = [self.storyboard instantiateViewControllerWithIdentifier:@"RWTTutorialStepViewController"];
  stepVC.bgImage = [UIImage imageNamed:bgImageName];
  stepVC.iconImage = [UIImage imageNamed:iconImageName];
  stepVC.text = text;
  [self.scrollView addSubview:stepVC.view];
  [self addChildViewController:stepVC];
  [stepVC didMoveToParentViewController:self];
  stepVC.view.translatesAutoresizingMaskIntoConstraints = NO;
  return stepVC;
}

- (void)viewDidLoad {

  [super viewDidLoad];

  self.step1VC = [self createStepVCWithBgImageName:@"bg_1" iconImageName:@"icon_1" text:@"PetShare is a pet photo sharing community."];
  self.step2VC = [self createStepVCWithBgImageName:@"bg_2" iconImageName:@"icon_2" text:@"Take pictures of your pet, and add filters or clipart to help them shine."];
  self.step3VC = [self createStepVCWithBgImageName:@"bg_3" iconImageName:@"icon_3" text:@"Share your photos via Facebook, email, Twitter, or instant message."];
  self.step4VC = [self createStepVCWithBgImageName:@"bg_4" iconImageName:@"icon_4" text:@"Rate other photos, give hearts, and follow pets you adore!"];
  self.step5VC = [self createStepVCWithBgImageName:@"bg_5" iconImageName:@"icon_5" text:@"Set up a profile for your pet, show past photos, and let fans follow."];
  
  NSDictionary *viewsDictionary = @{@"step1View": self.step1VC.view, @"step2View": self.step2VC.view, @"step3View": self.step3VC.view, @"step4View": self.step4VC.view, @"step5View": self.step5VC.view, @"mainView": self.view};
  
  NSArray *horzConstraints = [NSLayoutConstraint constraintsWithVisualFormat:@"|-(10)-[step1View(==mainView)]-(20)-[step2View(==mainView)]-(20)-[step3View(==mainView)]-(20)-[step4View(==mainView)]-(20)-[step5View(==mainView)]-(10)-|" options:0 metrics:nil views:viewsDictionary];
  [self.view addConstraints:horzConstraints];
  
  for (int i = 1; i <= 5; i++) {
    NSString *format = [NSString stringWithFormat:@"V:|[step%dView(==mainView)]|", i];
    NSArray *vertConstraints = [NSLayoutConstraint constraintsWithVisualFormat:format options:0 metrics:nil views:viewsDictionary];
    [self.view addConstraints:vertConstraints];
  }
  
  self.pageControl.numberOfPages = 5;
  
}

- (void)scrollViewDidScroll:(UIScrollView *)scrollView {

  CGFloat pageWidth = CGRectGetWidth(self.scrollView.bounds);
  CGFloat pageFraction = self.scrollView.contentOffset.x / pageWidth;
  self.pageControl.currentPage = roundf(pageFraction);

}

@end
